@@ -1,8 +1,9 @@
 /******************************************************************************
  *
- *  femain.h -	Implementation of FEMain
+ * femain.h -	class FEMain: a class which was meant to begin encapsulating
+ * 		frontend frameworks, but never really took off. Mostly unused.
  *
- * $Id: femain.h 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: femain.h 3786 2020-08-30 11:35:14Z scribe $
  *
  * Copyright 1998-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,12 +24,11 @@
 #ifndef FEMAIN_H
 #define FEMAIN_H
 
-class FEMain
-{
+class FEMain {
 public:
-  FEMain ();
-  virtual ~FEMain ();
-  list < SWDisplay * >displays;	// so we can delete each display we create
+	FEMain();
+	virtual ~FEMain();
+	list<SWDisplay *> displays;	// so we can delete each display we create
 };
 
 #endif
