@@ -2,7 +2,7 @@
  *
  *  thmlcgi.cpp -	ThMLCGI: ThML to Diatheke/CGI format filter
  *
- * $Id: thmlcgi.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: thmlcgi.cpp 3427 2016-07-03 14:30:33Z scribe $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -198,9 +198,10 @@ bool ThMLCGI::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *ba
 
 		else {
 			buf += '<';
-			for (i = 0; i < strlen(token); i++)
+			for (i = 0; i < strlen(token); i++) {
 				buf += token[i];
-				buf += '>';
+			}
+			buf += '>';
 			//return false;  // we still didn't handle token
 		}
 	}
